 #include <iostream>
 #include <fstream>
 #include <cstring>
 #include <cstdlib>
 #include <iomanip>
 #include <cmath>
 #include <ctime>
 
 /*---------------------------- Declaration of the main physical and mathematical constants ------------------------------------*/

  const double pi  =2.0*asin(1.0);   // number pi                               //
  const double re2 =7.940787682e-26; // square of electron's radius in cm^2     //
  const double mc2 =510.99895;       // electron's mass in keV                  // 
  const double Na  =6.02214076e23;   // Avogadro's number                       //
  const double h   =6.62607015e-34;  // Planck's constant in Js units           //
  const double e   =1.602176634e-19; // electron charge in C                    //
  const double c   =2.99792458e8;    // speed of light in m/s                   //
    
 /*-------- Declaration of constants specific to optimal grazing-incidence position (OGIP) XRF of trace elements in bone --------*/
  const double Lc = 20.0;    // Lc  = length of Al collimator in mm     //
  const double Dd = 5.6;     // detector diameter in mm                 //
  const double roSi=2.330;   // mass density of Si in g/cm^3 units      //
  const double roBe=1.850;   // mass density of Be in g/cm^3 units      //
  const double tSi=0.050;    // thickness of Si detector in cm units    //
  const double tBe=0.00125;  // thickness    of Be window in cm units   //
  
 /*------- Gaussian probabilities for G(x0,sigma) between a and b ---------------------------------------------------------------*/
 double GaussProb (double x0, double sigma, double a, double b)
 {
   double ll   = (a-x0)/sigma;
   double ul   = (b-x0)/sigma;
   double prob = 0.5*(erf(ul/sqrt(2.0))-erf(ll/sqrt(2.0)));
   return prob;
 }
  
 /*----------------------- Linear interpolation of x[] and y[] data arrays each containing N+1 values ---------------------------*/
 
 double linearint (double xx,double x[],double y[],int N)
 {
    double t;	
    if (xx==x[N])
	{t=y[N];}
	for (int i=0;i<N;i++)
	{
      if (xx==x[i])
	  {t=y[i];}
	  if ((xx>x[i])&&(xx<x[i+1]))
	  {t=((y[i+1]-y[i])*xx+(x[i+1]*y[i]-x[i]*y[i+1]))/(x[i+1]-x[i]);}
	}
	return t;
 }
 
 /*--- Calculation of an integral using trapezoidal method: deltax = x interval, integer n = number of points, and fv[] = function values ----*/
 
 double trapez (int n, double dx, double fv[])
 {
	 double s = 0.0;
	 for (int i=0;i<=n;i++)
	 {s=s+0.5*dx*(fv[i]+fv[i+1]);}
     return s; 
 }
 
 /*--------------- Cubic spline interpolation function given N values in x[] and y[] ----------------------------------------------*/
 double cspline (double xx,double x[],double y[],int N)
 {
   double p,sig,yy,yy1,yy2,A,B,C,D; 
   double y2[N],u[N];
   int i,k;
   y2[0]=u[0]=0.0; //set to 0 the lower boundary of the second derivative, the so-called "natural cubic spline" option // 
   //This is the decomposition loop of the tridiagonal algorithm, y2 and u vectors store the decomposed values         //
  for (i=1;i<N-1;i++)                 
   {
	sig=(x[i]-x[i-1])/(x[i+1]-x[i]);
	p=sig*y2[i-1]+2.0;
	y2[i]=(sig-1.0)/p;
	u[i]=(y[i+1]-y[i])/(x[i+1]-x[i])-(y[i]-y[i-1])/(x[i]-x[i-1]);
	u[i]=(6.0*u[i]/(x[i+1]-x[i-1])-sig*u[i-1])/p;	
   } 
  y2[N-1]=0.0;  //set to 0 the upper boundary of the second derivative, the so-called "natural cubic spline" option   //
  //This is the backsubstitution loop of the tridiagonal algorithm                                                    //
  for (k=N-2;k>=0;k--)
  {y2[k]=y2[k]*y2[k+1]+u[k];}

  for (i=0;i<=(N-1);i++)
   {
	 if ((xx>=x[i])&&(xx<=x[i+1]))
	   {
		A=(x[i+1]-xx)/(x[i+1]-x[i]);
        B=1.0-A;
        C=(A*A*A-A)*(x[i+1]-x[i])*(x[i+1]-x[i])/6.0;
		D=(B*B*B-B)*(x[i+1]-x[i])*(x[i+1]-x[i])/6.0;
		yy=A*y[i]+B*y[i+1]+C*y2[i]+D*y2[i+1];                                                                          // interpolated value  //
		yy1=(y[i+1]-y[i])/(x[i+1]-x[i])-(3.0*A*A-1.0)/6.0*(x[i+1]-x[i])*y2[i]+(3.0*B*B-1.0)/6.0*(x[i+1]-x[i])*y2[i+1]; // 1-st derivative     //
		yy2=A*y2[i]+B*y2[i+1];                                                                                         // 2-nd derivative     //
	   }
	}	 
  return yy; 
 }
 
 /*------ Linear or cubic spline interpolation of log-log photoelectric and total attenuation cross sections in cm^2/g ------------------------- */
    // q = 1 linear interpolation; q = 2 cubic spline interpolation // 
 double loglog (double E, double en[],double y[],int N, int q)
 {
	double logx[N],logy[N];
	for (int i=0;i<N;i++)
	{
	  logx[i]=log(en[i]);
	  logy[i]=log(y[i]);
	}
	double a=log(E);
	double res;
	if (q==1)
	{res=exp(linearint(a,logx,logy,N));}
    else
	{res=exp(cspline(a,logx,logy,N));}
	return res;
 }
 
 /*----------- Atomic mass of elements from Z=1 (H) to (Z=38) Sr in g/mol units------------------------------------------------------*/
 double atmass (double Z)
 {
	double y;
	if (Z==1.0)
	{y=1.008;}         // Atomic mass of hydrogen (H)   //
    if (Z==2.0)
	{y=4.002602;}      // Atomic mass of helium (He)    //
    if (Z==3.0)
	{y=6.94;}          // Atomic mass of lithium (Li)   //
    if (Z==4.0)
	{y=9.0121831;}     // Atomic mass of beryllium (Be) //
    if (Z==5.0)
	{y=10.81;}         // Atomic mass of boron (B)      //
    if (Z==6.0)
	{y=12.011;}        // Atomic mass of carbon (C)     //
    if (Z==7.0)
	{y=14.007;}        // Atomic mass of nitrogen (N)   //
    if (Z==8.0)
	{y=15.999;}        // Atomic mass of oxygen (O)     //
    if (Z==9.0)
	{y=18.99840316;}   // Atomic mass of fluorine (F)   //
    if (Z==10.0)
	{y=20.1797;}       // Atomic mass of neon (Ne)      //
    if (Z==11.0)
	{y=22.98976928;}   // Atomic mass of sodium (Na)    //
    if (Z==12.0)
	{y=24.035;}        // Atomic mass of magnesium (Mg) //
    if (Z==13.0)
	{y=26.9815385;}    // Atomic mass of aluminum (Al)  //
    if (Z==14.0)
	{y=28.085;}        // Atomic mass of silicon (Si)   //
    if (Z==15.0)
	{y=30.97376200;}   // Atomic mass of phosphorus (P) //
    if (Z==16.0)
	{y=32.06;}         // Atomic mass of sulfur (S)     //
    if (Z==17.0)
	{y=35.45;}         // Atomic mass of chlorine (Cl)  //
    if (Z==18.0)
	{y=39.948;}        // Atomic mass of argon (Ar)     //
    if (Z==19.0)
	{y=39.0983;}       // Atomic mass of potassium (K)  //
    if (Z==20.0)
	{y=40.078;}        // Atomic mass of calcium (Ca)   //
    if (Z==21.0)
	{y=44.955908;}     // Atomic mass of scandium (Sc)  //
    if (Z==22.0)
	{y=47.867;}        // Atomic mass of titanium (Ti)  //
    if (Z==23.0)
	{y=50.9415;}       // Atomic mass of vanadium (V)   //
    if (Z==24.0)
	{y=51.9961;}       // Atomic mass of chromium (Cr)  //
    if (Z==25.0)
	{y=54.938044;}     // Atomic mass of manganese (Mn) //
    if (Z==26.0)
	{y=55.845;}        // Atomic mass of iron (Fe)      //
    if (Z==27.0)
	{y=58.933194;}     // Atomic mass of cobalt (Co)    //
    if (Z==28.0)
	{y=58.6934;}       // Atomic mass of nickel (Ni)    //
    if (Z==29.0)
	{y=63.546;}        // Atomic mass of copper (Cu)    //
    if (Z==30.0)
	{y=65.38;}         // Atomic mass of zinc (Zn)      //
    if (Z==31.0)
	{y=69.723;}        // Atomic mass of gallium (Ga)   //
    if (Z==32.0)
	{y=72.630;}        // Atomic mass of germanium (Ge) //
    if (Z==33.0)
	{y=74.921595;}     // Atomic mass of arsenic (As)   //
    if (Z==34.0)
	{y=78.971;}        // Atomic mass of selenium (Se)  //
    if (Z==35.0)
	{y=79.904;}        // Atomic mass of bromine (Br)   //
    if (Z==36.0)
	{y=83.798;}        // Atomic mass of krypton (Kr)   //
    if (Z==37.0)
	{y=85.4678;}       // Atomic mass of rubidium (Rb)  //
    if (Z==38.0)
	{y=87.62;}         // Atomic mass of strontium (Sr) //
  return y;
 }
 
 /*-------- Approx. Ka and Kb photon energies in keV for 25 elements from Si (Z=14) to Sr (Z=38), a=1 Ka energy, a=2 Kb energy ----------*/ 
 
 double Ken (double Z, int a)
 {
  double E;
  
  if ((Z==14.0)&(a==1))  // Approximate Ka photon energy in keV of silicon (Si), Z=14  //
  {E=1.74;}
  if ((Z==14.0)&(a==2))  // Approximate Kb photon energy in keV of silicon (Si), Z=14  //
  {E=1.84;}

  if ((Z==15.0)&(a==1))  // Approximate Ka photon energy in kev of phosphorus (P), Z=15 //
  {E=2.01;}
  if ((Z==15.0)&(a==2))  // Approximate Kb photon energy in kev of phosphorus (P), Z=15 //
  {E=2.14;}

  if ((Z==16.0)&(a==1))  // Approximate Ka photon energy in keV of sulfur (S), Z=16     //
  {E=2.31;}
  if ((Z==16.0)&(a==2))  // Approximate Kb photon energy in keV of sulfur (S), Z=16     //
  {E=2.46;}

  if ((Z==17.0)&(a==1))  // Approximate Ka photon energy in keV of chlorine (Cl), Z=17  //
  {E=2.62;}
  if ((Z==17.0)&(a==2))  // Approximate Kb photon energy in keV of chlorine (Cl), Z=17  //
  {E=2.82;}

  if ((Z==18.0)&(a==1))  // Approximate Ka photon energy in keV of argone (Ar), Z=18    //
  {E=2.96;}
  if ((Z==18.0)&(a==2))  // Approximate Kb photon energy in keV of argone (Ar), Z=18    //
  {E=3.19;}

  if ((Z==19.0)&(a==1))  // Approximate Ka photon energy in keV of potassium (K), Z=19  //
  {E=3.31;}
  if ((Z==19.0)&(a==2))  // Approximate Kb photon energy in keV of potassium (K), Z=19  //
  {E=3.59;}

  if ((Z==20.0)&(a==1))  // Approximate Ka photon energy in keV of calcium (Ca), Z=20   //
  {E=3.69;}
  if ((Z==20.0)&(a==2))  // Approximate Kb photon energy in keV of calcium (Ca), Z=20   //
  {E=4.01;}

  if ((Z==21.0)&(a==1))  // Approximate Ka photon energy in keV of scandium (Sc), Z=21  //
  {E=4.09;}
  if ((Z==21.0)&(a==2))  // Approximate Ka photon energy in keV of scandium (Sc), Z=21  //
  {E=4.46;}

  if ((Z==22.0)&(a==1))  // Approximate Ka photon energy in keV of titanium (Ti), Z=22  //
  {E=4.51;}
  if ((Z==22.0)&(a==2))  // Approximate Kb photon energy in keV of titanium (Ti), Z=22  //
  {E=4.93;}

  if ((Z==23.0)&(a==1))  // Approximate Ka photon energy in keV of vanadium (V), Z=23   //
  {E=4.95;}
  if ((Z==23.0)&(a==2))  // Approximate Kb photon energy in keV of vanadium (V), Z=23   //
  {E=5.43;}

  if ((Z==24.0)&(a==1))  // Approximate Ka photon energy in keV of chromium (Cr), Z=24  //
  {E=5.41;}
  if ((Z==24.0)&(a==2))  // Approximate Kb photon energy in keV of chromium (Cr), Z=24  //
  {E=5.95;}

  if ((Z==25.0)&(a==1))  // Approximate Ka photon energy in keV of manganese (Mn), Z=25 //
  {E=5.90;}
  if ((Z==25.0)&(a==2))  // Approximate Kb photon energy in keV of manganese (Mn), Z=25 //
  {E=6.49;}

  if ((Z==26.0)&(a==1))  // Approximate Ka photon energy in keV of iron (Fe), Z=26      //
  {E=6.40;}
  if ((Z==26.0)&(a==2))  // Approximate Kb photon energy in keV of iron (Fe), Z=26      //
  {E=7.06;}

  if ((Z==27.0)&(a==1))  // Approximate Ka photon energy in keV of cobalt (Co), Z=27    // 
  {E=6.92;}
  if ((Z==27.0)&(a==2))  // Approximate Kb photon energy in keV of cobalt (Co), Z=27    //
  {E=7.65;}

  if ((Z==28.0)&(a==1))  // Approximate Ka photon energy in keV of nickel (Ni), Z=28    //
  {E=7.47;}
  if ((Z==28.0)&(a==2))  // Approximate Kb photon energy in keV of nickel (Ni), Z=28    //
  {E=8.27;}

  if ((Z==29.0)&(a==1))  // Approximate Ka photon energy in keV of copper Cu), Z=29     //
  {E=8.04;}
  if ((Z==29.0)&(a==2))  // Approximate Kb photon energy in keV of copper Cu), Z=29     //
  {E=8.91;}

  if ((Z==30.0)&(a==1))  // Approximate Ka photon energy in keV of zinc (Zn), Z=30      //
  {E=8.63;}
  if ((Z==30.0)&(a==2))  // Approximate Kb photon energy in keV of zinc (Zn), Z=30      //
  {E=9.57;}

  if ((Z==31.0)&(a==1))  // Approximate Ka photon energy in keV of galium (Ga), Z=31    //
  {E=9.24;}
  if ((Z==31.0)&(a==2))  // Approximate Kb photon energy in keV of galium (Ga), Z=31    //
  {E=10.26;}

  if ((Z==32.0)&(a==1))  // Approximate Ka photon energy in keV of germanium (Ge), Z=32 //
  {E=9.89;}
  if ((Z==32.0)&(a==2))  // Approximate Kb photon energy in keV of germanium (Ge), Z=32 //
  {E=10.98;}

  if ((Z==33.0)&(a==1))  // Approximate Ka photon energy in keV of arsenic (As), Z=33   //
  {E=10.53;}
  if ((Z==33.0)&(a==2))  // Approximate Kb photon energy in keV of arsenic (As), Z=33   //
  {E=11.73;}

  if ((Z==34.0)&(a==1))  // Approximate Ka photon energy in keV of selenium (Se), Z=34  //
  {E=11.21;}
  if ((Z==34.0)&(a==2))  // Approximate Kb photon energy in keV of selenium (Se), Z=34  //
  {E=12.50;}

  if ((Z==35.0)&(a==1))  // Approximate Ka photon energy in keV of bromine (Br), Z=35   //
  {E=11.90;}
  if ((Z==35.0)&(a==2))  // Approximate Kb photon energy in keV of bromine (Br), Z=35   //
  {E=13.29;}

  if ((Z==36.0)&(a==1))  // Approximate Ka photon energy in keV of krypton (Kr), Z=36   //
  {E=12.64;}
  if ((Z==36.0)&(a==2))  // Approximate Kb photon energy in keV of krypton (Kr), Z=36   //
  {E=14.11;}

  if ((Z==37.0)&(a==1))  // Approximate Ka photon energy in keV of rubidium (Rb), Z=37  //
  {E=13.35;}
  if ((Z==37.0)&(a==2))  // Approximate Kb photon energy in keV of rubidium (Rb), Z=37  //
  {E=14.96;}

  if ((Z==38.0)&(a==1))  // Approximate Ka photon energy in keV of strontium (Sr), Z=38 //
  {E=14.14;}
  if ((Z==38.0)&(a==2))  // Approximate Kb photon energy in keV of strontium (Sr), Z=38 //
  {E=15.84;}

  return E;
}
 /*--------XCOM statement on interpolation and combination of x-ray interactions atomic cross section data---------------------------------
 For the purpose of interpolation with respect to photon energy, the coherent and incoherent scattering cross sections and 
 the total attenuation coefficients are approximated by log-log cubic-spline fits as functions of energy. 
 For the pair-production cross sections, the fitted quantity is the logarithm of the quantity (1-E/E′)3 σPAIR(E), 
 where E is the photon energy, E′ the threshold energy for pair production, and σPAIR(E) is the cross section. 
 The fitting is done separately for pair production in the field of the atomic nucleus (E′ = 1.022 MeV) and in the field of 
 the atomic electrons (E′ = 2.044 MeV).
 The combined photoelectric absorption cross section for all shells is similarly interpolated with use of log-log cubic-spline fits, 
 but only at energies above the K-shell absorption edge. 
 Below this energy, interpolation is applied to the logarithm of the photoelectric absorption cross section for each separate shell, 
 fitted as a linear function of the logarithm of the photon energy. 
 The separate fitting for each shell is necessary to avoid the error that would be incurred by interpolating across absorption edges. 
 Linear log-log fitting is equivalent to assuming that the photoelectric cross section is proportional to a power of the photon energy, 
 and was found to provide more satisfactory fits than a log-log cubic-spline fit near the absorption edges.
 The interaction coefficients and total attenuation coefficients for compounds are obtained as weighted sums over the corresponding
 coefficients for elements. 
 XCOM automatically calculates the weight factors, i.e., the fractions by weights of the atomic constituents, 
 from the chemical formula for the compound entered by the user. 
 For mixtures, the user must enter the fractions by weight of the components.
--------------------------------------------------------------------------------------------------------------------------------------------*/

/*---- Mass attenuation coefficients: total (a=0), photoelectric (a=1) for 12 elements in the 1 keV to 100 keV photon energy range in cm^2/g units ---------*/
 
 double matt(double Z, double E, int a)
 {
   double y,y0,y1,EK,EL1,EL2,EL3;
   int N; 
   y=0.0; y0=0.0; y1=0.0;
     if (Z==1.0)  //Hydrogen (H) mass att. coeff. in the 1 keV to 100 keV photon energy range from log-log cubic spline interpolation of XCOM data// 
	{
     N=17;
	 double en[] ={1.000E+00,1.500E+00,2.000E+00,3.000E+00,4.000E+00,5.000E+00,6.000E+00,8.000E+00,1.000E+01,1.500E+01,2.000E+01,
	                3.000E+01,4.000E+01,5.000E+01,6.000E+01,8.000E+01,1.000E+02};	 
	 double miu[]={7.214E+00,2.148E+00,1.059E+00,5.611E-01,4.546E-01,4.193E-01,4.042E-01,3.914E-01,3.854E-01,3.764E-01,3.6950E-01,
	                3.570E-01,3.458E-01,3.355E-01,3.260E-01,3.091E-01,2.944E-01};
	 double tau[]={6.817E+00,1.752E+00,6.638E-01,1.677E-01,6.291E-02,2.932E-02,1.570E-02,5.865E-03,2.723E-03,6.739E-04,2.499E-04,
	                6.166E-05,2.284E-05,1.058E-05,5.649E-06,2.105E-06,9.822E-07};
	 y0=loglog(E,en,miu,N,2);
	 y1=loglog(E,en,tau,N,2);
	}
	 if (Z==4.0) //Beryllium (Be) mass att. coeff. in the 1 keV to 100 keV photon energy range from log-log cubic spline interpolation of XCOM data//
	{  
     N=17;
	 double en[] ={1.000E+00,1.500E+00,2.000E+00,3.000E+00,4.000E+00,5.000E+00,6.000E+00,8.000E+00,1.000E+01,1.500E+01,2.000E+01, 3.000E+01,4.000E+01,5.000E+01,6.000E+01,8.000E+01,1.000E+02};
     double miu[]={6.042E+02,1.797E+02,7.470E+01,2.127E+01,8.685E+00,4.369E+00,2.528E+00,1.124E+00,6.466E-01,3.070E-01,2.251E-01,1.792E-01,1.640E-01,1.554E-01,1.493E-01,1.401E-01,1.328E-01};
	 double tau[]={6.035E+02,1.792E+02,7.424E+01,2.090E+01,8.366E+00,4.081E+00,2.259E+00,8.821E-01,4.229E-01,1.101E-01,4.207E-02,1.077E-02,4.080E-03,1.919E-03,1.039E-03,3.936E-04,1.859E-04};
	 y0=loglog(E,en,miu,N,2);
	 y1=loglog(E,en,tau,N,2);
	}
	 if (Z==6.0) //Carbon (C) mass att. coeff. in the 1 keV to 100 keV photon energy range from log-log cubic spline interpolation of XCOM data//
	{
	 N=17;
	 double en[] ={1.000E+00,1.500E+00,2.000E+00,3.000E+00,4.000E+00,5.000E+00,6.000E+00,8.000E+00,1.000E+01,1.500E+01,2.000E+01,3.000E+01,4.000E+01,5.000E+01,6.000E+01,8.000E+01,1.000E+02};
	 double miu[]={2.211E+03,7.004E+02,3.026E+02,9.032E+01,3.778E+01,1.912E+01,1.095E+01,4.576E+00,2.373E+00,8.074E-01,4.420E-01,2.562E-01,2.076E-01,1.871E-01,1.753E-01,1.610E-01,1.514E-01};  
	 double tau[]={2.210E+03,6.994E+02,3.017E+02,8.965E+01,3.724E+01,1.866E+01,1.054E+01,4.241E+00,2.076E+00,5.585E-01,2.177E-01,5.706E-02,2.193E-02,1.042E-02,5.671E-03,2.169E-03,1.031E-03};
	 y0=loglog(E,en,miu,N,2);
     y1=loglog(E,en,tau,N,2);
	}
	 if (Z==7.0) //Nitrogen (N) mass att. coeff. in the 1 keV to 100 keV photon energy range from log-log cubic spline interpolation of XCOM data//
	{
	 N=17;
	 double en[] ={1.000E+00,1.500E+00,2.000E+00,3.000E+00,4.000E+00,5.000E+00,6.000E+00,8.000E+00,1.000E+01,1.500E+01,2.000E+01,3.000E+01,4.000E+01,5.000E+01,6.000E+01,8.000E+01,1.000E+02};
	 double miu[]={3.311E+03,1.083E+03,4.770E+02,1.456E+02,6.166E+01,3.144E+01,1.808E+01,7.559E+00,3.879E+00,1.236E+00,6.179E-01,3.066E-01,2.288E-01,1.980E-01,1.817E-01,1.639E-01,1.529E-01}; 
	 double tau[]={3.310E+03,1.081E+03,4.759E+02,1.448E+02,6.097E+01,3.087E+01,1.759E+01,7.167E+00,3.543E+00,9.674E-01,3.808E-01,1.010E-01,3.907E-02,1.866E-02,1.019E-02,3.919E-03,1.869E-03};
	 y0=loglog(E,en,miu,N,2);
	 y1=loglog(E,en,tau,N,2);					
	}
	 if (Z==8.0) //Oxygen (O) mass att. coeff. in the 1 keV to 100 keV photon energy range from log-log cubic spline interpolation of XCOM data//
	{
     N=17;
	 double en[] ={1.000E+00,1.500E+00,2.000E+00,3.000E+00,4.000E+00,5.000E+00,6.000E+00,8.000E+00,1.000E+01,1.500E+01,2.000E+01,3.000E+01,4.000E+01,5.000E+01,6.000E+01,8.000E+01,1.000E+02};
	 double miu[]={4.590E+03,1.549E+03,6.950E+02,2.171E+02,9.315E+01,4.791E+01,2.770E+01,1.163E+01,5.953E+00,1.836E+00,8.653E-01,3.779E-01,2.585E-01,2.133E-01,1.907E-01,1.679E-01,1.551E-01};
	 double tau[]={4.588E+03,1.547E+03,6.937E+02,2.160E+02,9.229E+01,4.720E+01,2.710E+01,1.117E+01,5.567E+00,1.542E+00,6.124E-01,1.641E-01,6.395E-02,3.068E-02,1.681E-02,6.497E-03,3.111E-03};
	 y0=loglog(E,en,miu,N,2);
	 y1=loglog(E,en,tau,N,2);
	}
	 if (Z==11.0) //Sodium (Na) mass att. coeff. in the 1 keV to 100 keV photon energy range from log-log cubic spline interpolation of XCOM data//
	{
	  EK=1.072E+00;
	  if (E<=EK)
	  {
		N=3;
		double en[] ={1.000E+00,1.035E+00,1.072E+00};
		double miu[]={6.542E+02,5.958E+02,5.431E+02};
	    double tau[]={6.523E+02,5.939E+02,5.412E+02};
		y0=loglog(E,en,miu,N,1);
		y1=loglog(E,en,tau,N,1);
	  }
	  if (E>EK)
	  {
		N=17;
		double en[] ={1.072E+00,1.500E+00,2.000E+00,3.000E+00,4.000E+00,5.000E+00,6.000E+00,8.000E+00,1.000E+01,1.500E+01,2.000E+01,3.000E+01,4.000E+01,5.000E+01,6.000E+01,8.000E+01,1.000E+02};
		double miu[]={6.435E+03,3.195E+03,1.521E+03,5.070E+02,2.261E+02,1.194E+02,7.030E+01,3.018E+01,1.557E+01,4.694E+00,2.057E+00,7.198E-01,3.969E-01,2.804E-01,2.268E-01,1.796E-01,1.585E-01};
	    double tau[]={6.433E+03,3.193E+03,1.519E+03,5.056E+02,2.249E+02,1.183E+02,6.939E+01,2.950E+01,1.502E+01,4.317E+00,1.756E+00,4.854E-01,1.927E-01,9.370E-02,5.187E-02,2.032E-02,9.826E-03};
		y0=loglog(E,en,miu,N,2);
		y1=loglog(E,en,tau,N,2);
	  } 
	}
	 if (Z==12.0) //Magnesium (Mg) mass att. coeff. in the 1 keV to 100 keV photon energy range from log-log cubic spline interpolation of XCOM data//
	{
	  EK=1.305E+00;
	  if (E<=EK)
	  {
		N=3;
		double en[] ={1.000E+00,1.142E+00,1.305E+00}; 
		double miu[]={9.224E+02,6.463E+02,4.530E+02};
	    double tau[]={9.202E+02,6.442E+02,4.509E+02};
		y0=loglog(E,en,miu,N,1);
		y1=loglog(E,en,tau,N,1);
	  }
	  if (E>EK)
	  {
		N=17;
		double en[] ={1.305E+00,1.500E+00,2.000E+00,3.000E+00,4.000E+00,5.000E+00,6.000E+00,8.000E+00,1.000E+01,1.500E+01,2.000E+01,3.000E+01,4.000E+01,5.000E+01,6.000E+01,8.000E+01,1.000E+02};
		double miu[]={5.443E+03,4.004E+03,1.932E+03,6.584E+02,2.974E+02,1.583E+02,9.380E+01,4.059E+01,2.106E+01,6.357E+00,2.763E+00,9.304E-01,4.880E-01,3.292E-01,2.570E-01,1.951E-01,1.686E-01};
	    double tau[]={5.441E+03,4.002E+03,1.930E+03,6.568E+02,2.961E+02,1.571E+02,9.279E+01,3.982E+01,2.043E+01,5.937E+00,2.433E+00,6.784E-01,2.711E-01,1.324E-01,7.346E-02,2.894E-02,1.403E-02};
		y0=loglog(E,en,miu,N,2);
		y1=loglog(E,en,tau,N,2);
	  }
	}
	 if (Z==14.0) //Silicon (Si) mass att. coeff. in the 1 keV to 100 keV photon energy range from log-log cubic spline interpolation of XCOM data//
	{
      EK=1.839E+00;
	  if (E<=EK)
	  {
		N=3;
		double en[] ={1.000E+00,1.500E+00,1.839E+00};
		double miu[]={1.570E+03,5.356E+02,3.092E+02};	
	    double tau[]={1.567E+03,5.333E+02,3.071E+02};
		y0=loglog(E,en,miu,N,1);
		y1=loglog(E,en,tau,N,1);
	  }
	  if (E>EK)
	  {
		N=16;
		double en[] ={1.839E+00,2.000E+00,3.000E+00,4.000E+00,5.000E+00,6.000E+00,8.000E+00,1.000E+01,1.500E+01,2.000E+01,3.000E+01,4.000E+01,5.000E+01,6.000E+01,8.000E+01,1.000E+02};
		double miu[]={3.193E+03,2.777E+03,9.784E+02,4.528E+02,2.451E+02,1.470E+02,6.469E+01,3.388E+01,1.034E+01,4.463E+00,1.436E+00,7.010E-01,4.385E-01,3.206E-01,2.228E-01,1.835E-01};
	    double tau[]={3.191E+03,2.775E+03,9.767E+02,4.514E+02,2.438E+02,1.458E+02,6.379E+01,3.315E+01,9.848E+00,4.089E+00,1.161E+00,4.687E-01,2.307E-01,1.288E-01,5.120E-02,2.498E-02};
		y0=loglog(E,en,miu,N,2);
		y1=loglog(E,en,tau,N,2);
	  }
	}	
	 if (Z==15.0) //Phosphorus (P) mass att. coeff. in the 1 keV to 100 keV photon energy range from log-log cubic spline interpolation of XCOM data//
	{
	  EK=2.145E+00;
	  if (E<=EK)
	  {
		N=4;
		double en[] ={1.000E+00,1.500E+00,2.000E+00,2.145E+00}; 
		double miu[]={1.913E+03,6.547E+02,3.018E+02,2.494E+02};	
	    double tau[]={1.910E+03,6.523E+02,2.996E+02,2.473E+02};
		y0=loglog(E,en,miu,N,1);
		y1=loglog(E,en,tau,N,1);
	  }
	  if (E>EK)
	  {
		N=15;
		double en[] ={2.145E+00,3.000E+00,4.000E+00,5.000E+00,6.000E+00,8.000E+00,1.000E+01,1.500E+01,2.000E+01,3.000E+01,4.000E+01,5.000E+01,6.000E+01,8.000E+01,1.000E+02};
		double miu[]={2.473E+03,1.118E+03,5.241E+02,2.861E+02,1.726E+02,7.660E+01,4.036E+01,1.239E+01,5.354E+00,1.700E+00,8.095E-01,4.918E-01,3.494E-01,2.324E-01,1.865E-01};
	    double tau[]={2.471E+03,1.116E+03,5.226E+02,2.848E+02,1.715E+02,7.567E+01,3.960E+01,1.188E+01,4.970E+00,1.421E+00,5.771E-01,2.852E-01,1.597E-01,6.369E-02,3.117E-02};
		y0=loglog(E,en,miu,N,2);
		y1=loglog(E,en,tau,N,2);
	  }
	}
	if (Z==16.0) //Sulfur (S) mass att. coeff. in the 1 keV to 100 keV photon energy range from log-log cubic spline interpolation of XCOM data//
	{
      EK=2.472E+00;
	  if (E<=EK)
	  {
		N=4;
		double en[] ={1.000E+00,1.500E+00,2.000E+00,2.472E+00}; 
		double miu[]={2.429E+03,8.341E+02,3.852E+02,2.169E+02};
	    double tau[]={2.426E+03,8.314E+02,3.827E+02,2.147E+02};
		y0=loglog(E,en,miu,N,1);
		y1=loglog(E,en,tau,N,1);
	  }
	  if (E>EK)
	  {
		N=15;
		double en[] ={2.472E+00,3.000E+00,4.000E+00,5.000E+00,6.000E+00,8.000E+00,1.000E+01,1.500E+01,2.000E+01,3.000E+01,4.000E+01,5.000E+01,6.000E+01,8.000E+01,1.000E+02};
		double miu[]={2.070E+03,1.339E+03,6.338E+02,3.487E+02,2.116E+02,9.464E+01,5.013E+01,1.550E+01,6.709E+00,2.113E+00,9.872E-01,5.849E-01,4.052E-01,2.586E-01,2.020E-01};
	    double tau[]={2.068E+03,1.337E+03,6.321E+02,3.473E+02,2.103E+02,9.364E+01,4.930E+01,1.495E+01,6.290E+00,1.814E+00,7.403E-01,3.670E-01,2.060E-01,8.256E-02,4.051E-02};
		y0=loglog(E,en,miu,N,2);
		y1=loglog(E,en,tau,N,2);		
	  }
	}
	if (Z==17.0) //Chlorine (Cl) mass att. coeff. in the 1 keV to 100 keV photon energy range from log-log cubic spline interpolation of XCOM data//
	{
      EK=2.822E+00;
      if (E<=EK)
	  {
		N=4;
		double en[] ={1.000E+00,1.500E+00,2.000E+00,2.822E+00}; 
		double miu[]={2.831E+03,9.772E+02,4.520E+02,1.775E+02};
	    double tau[]={2.828E+03,9.743E+02,4.495E+02,1.753E+02};
		y0=loglog(E,en,miu,N,1);
		y1=loglog(E,en,tau,N,1);
	  }
	  if (E>EK)
	  {
		N=15;
		double en[] ={2.822E+00,3.000E+00,4.000E+00,5.000E+00,6.000E+00,8.000E+00,1.000E+01,1.500E+01,2.000E+01,3.000E+01,4.000E+01,5.000E+01,6.000E+01,8.000E+01,1.000E+02};
		double miu[]={1.637E+03,1.473E+03,7.038E+02,3.901E+02,2.384E+02,1.075E+02,5.725E+01,1.784E+01,7.740E+00,2.426E+00,1.117E+00,6.483E-01,4.394E-01,2.696E-01,2.050E-01};
	    double tau[]={1.634E+03,1.471E+03,7.020E+02,3.886E+02,2.371E+02,1.065E+02,5.641E+01,1.728E+01,7.314E+00,2.127E+00,8.719E-01,4.338E-01,2.443E-01,9.825E-02,4.834E-02};
		y0=loglog(E,en,miu,N,2);
		y1=loglog(E,en,tau,N,2);		
	  }
	}
	if (Z==19.0) //Potassium (K) mass att. coeff. in the 1 keV to 100 keV photon energy range from log-log cubic spline interpolation of XCOM data//
	{
      EK=3.607E+00;
	  if (E<=EK)
	  {
		N=5;
		double en[]={1.000E+00,1.500E+00,2.000E+00,3.000E+00,3.607E+00}; 
		double miu[]={4.057E+03,1.418E+03,6.593E+02,2.199E+02,1.327E+02};
	    double tau[]={4.054E+03,1.415E+03,6.565E+02,2.175E+02,1.306E+02};
		y0=loglog(E,en,miu,N,1);
		y1=loglog(E,en,tau,N,1);	
	  }
	  if (E>EK)
	  {
		N=14;
		double en[] ={3.607E+00,4.000E+00,5.000E+00,6.000E+00,8.000E+00,1.000E+01,1.500E+01,2.000E+01,3.000E+01,4.000E+01,5.000E+01,6.000E+01,8.000E+01,1.000E+02};
		double miu[]={1.201E+03,9.255E+02,5.189E+02,3.204E+02,1.469E+02,7.907E+01,2.502E+01,1.093E+01,3.412E+00,1.541E+00,8.678E-01,5.678E-01,3.251E-01,2.345E-01};
	    double tau[]={1.199E+03,9.235E+02,5.172E+02,3.190E+02,1.458E+02,7.814E+01,2.438E+01,1.045E+01,3.084E+00,1.277E+00,6.398E-01,3.623E-01,1.468E-01,7.264E-02};
		y0=loglog(E,en,miu,N,2);
		y1=loglog(E,en,tau,N,2);
	  }
	}
	if (Z==20.0) //Calcium (Ca) mass att. coeff. in the 1 keV to 100 keV photon energy range from log-log cubic spline interpolation of XCOM data//
	{
	  EK=4.038E+00;
	  if (E<=EK)
	  {
		N=6;
		double en[] ={1.000E+00,1.500E+00,2.000E+00,3.000E+00,4.000E+00,4.038E+00};
		double miu[]={4.866E+03,1.713E+03,7.998E+02,2.676E+02,1.218E+02,1.187E+02};
	    double tau[]={4.862E+03,1.710E+03,7.968E+02,2.651E+02,1.197E+02,1.166E+02};
		y0=loglog(E,en,miu,N,1);
		y1=loglog(E,en,tau,N,1);	
	  }
	  if (E>EK)
	  {
		N=13;
		double en[] ={4.038E+00,5.000E+00,6.000E+00,8.000E+00,1.000E+01,1.500E+01,2.000E+01,3.000E+01,4.000E+01,5.000E+01,6.000E+01,8.000E+01,1.000E+02};
		double miu[]={1.023E+03,6.025E+02,3.731E+02,1.727E+02,9.341E+01,2.979E+01,1.306E+01,4.079E+00,1.830E+00,1.019E+00,6.579E-01,3.655E-01,2.571E-01}; 
	    double tau[]={1.021E+03,6.007E+02,3.716E+02,1.714E+02,9.241E+01,2.911E+01,1.255E+01,3.729E+00,1.552E+00,7.800E-01,4.428E-01,1.800E-01,8.931E-02};
		y0=loglog(E,en,miu,N,2);
		y1=loglog(E,en,tau,N,2);		
	  }
	}
	if (Z==25.0) //Manganese (Mn) mass att. coeff. in the 1 keV to 100 keV photon energy range from log-log cubic spline interpolation of XCOM data//
	{
      EK=6.539E+00;
	  if (E<=EK)
	  {
		N=8;
		double en[] ={1.000E+00,1.500E+00,2.000E+00,3.000E+00,4.000E+00,5.000E+00,6.000E+00,6.539E+00};
		double miu[]={8.093E+03,2.983E+03,1.421E+03,4.851E+02,2.229E+02,1.212E+02,7.350E+01,5.803E+01};
	    double tau[]={8.089E+03,2.979E+03,1.417E+03,4.820E+02,2.202E+02,1.189E+02,7.156E+01,5.623E+01};
		y0=loglog(E,en,miu,N,1);
		y1=loglog(E,en,tau,N,1);	
	  }
	  if (E>EK)
	  {
		N=11;
		double en[] ={6.539E+00,8.000E+00,1.000E+01,1.500E+01,2.000E+01,3.000E+01,4.000E+01,5.000E+01,6.000E+01,8.000E+01,1.000E+02};
		double miu[]={4.520E+02,2.734E+02,1.514E+02,5.027E+01,2.253E+01,7.142E+00,3.169E+00,1.714E+00,1.060E+00,5.306E-01,3.366E-01};
	    double tau[]={4.502E+02,2.720E+02,1.502E+02,4.948E+01,2.193E+01,6.753E+00,2.873E+00,1.467E+00,8.424E-01,3.486E-01,1.751E-01};	
		y0=loglog(E,en,miu,N,2);
		y1=loglog(E,en,tau,N,2);
	  }
	} 
	if (Z==26.0) //Iron (Fe) mass att. coeff. in the 1 keV to 100 keV photon energy range from log-log cubic spline interpolation of XCOM data//
	{
      EK=7.112E+00;
	  if (E<=EK)
	  {
		N=8;
		double en[] ={1.000E+00,1.500E+00,2.000E+00,3.000E+00,4.000E+00,5.000E+00,6.000E+00,7.112E+00};
		double miu[]={9.085E+03,3.400E+03,1.627E+03,5.576E+02,2.567E+02,1.399E+02,8.484E+01,5.320E+01};
	    double tau[]={9.081E+03,3.396E+03,1.623E+03,5.543E+02,2.538E+02,1.374E+02,8.272E+01,5.138E+01};
		y0=loglog(E,en,miu,N,1);
		y1=loglog(E,en,tau,N,1);
	  }
	  if (E>EK)
	  {
		N=11;
		double en[] ={7.112E+00,8.000E+00,1.000E+01,1.500E+01,2.000E+01,3.000E+01,4.000E+01,5.000E+01,6.000E+01,8.000E+01,1.000E+02};
		double miu[]={4.077E+02,3.056E+02,1.707E+02,5.709E+01,2.568E+01,8.176E+00,3.629E+00,1.957E+00,1.205E+00,5.952E-01,3.717E-01};
	    double tau[]={4.059E+02,3.040E+02,1.694E+02,5.623E+01,2.505E+01,7.763E+00,3.316E+00,1.697E+00,9.776E-01,4.060E-01,2.045E-01};
		y0=loglog(E,en,miu,N,2);
		y1=loglog(E,en,tau,N,2);		
	  }
	} 
	if (Z==27.0) //Cobalt (Co) mass att. coeff. in the 1 keV to 100 keV photon energy range from log-log cubic spline interpolation of XCOM data//
	{
      EK=7.709E+00;
	  if (E<=EK)
	  {
		N=8;
		double en[] ={1.000E+00,1.500E+00,2.000E+00,3.000E+00,4.000E+00,5.000E+00,6.000E+00,7.709E+00};
		double miu[]={9.795E+03,3.696E+03,1.779E+03,6.129E+02,2.830E+02,1.543E+02,9.372E+01,4.711E+01};
	    double tau[]={9.790E+03,3.692E+03,1.775E+03,6.093E+02,2.800E+02,1.517E+02,9.149E+01,4.535E+01};
		y0=loglog(E,en,miu,N,1);
		y1=loglog(E,en,tau,N,1);
	  }
	  if (E>EK)
	  {
		N=11;
		double en[] ={7.709E+00,8.000E+00,1.000E+01,1.500E+01,2.000E+01,3.000E+01,4.000E+01,5.000E+01,6.000E+01,8.000E+01,1.000E+02};
		double miu[]={3.555E+02,3.248E+02,1.842E+02,6.201E+01,2.803E+01,8.962E+00,3.980E+00,2.144E+00,1.314E+00,6.414E-01,3.950E-01};
	    double tau[]={3.538E+02,3.231E+02,1.828E+02,6.113E+01,2.738E+01,8.538E+00,3.661E+00,1.881E+00,1.085E+00,4.521E-01,2.282E-01};
		y0=loglog(E,en,miu,N,2);
		y1=loglog(E,en,tau,N,2);		
	  }
	} 
	if (Z==28.0) //Nickel (Ni) mass att. coeff. in the 1 keV to 100 keV photon energy range from log-log cubic spline interpolation of XCOM data//
	{
      EL1=1.008E+00;
	  EK=8.333E+00;
	  if (E<=EL1)
	  {
		N=3;
		double en[] ={1.000E+00,1.004E+00,1.008E+00}; 
		double miu[]={9.856E+03,9.753E+03,9.656E+03};
	    double tau[]={9.850E+03,9.748E+03,9.651E+03};
	    y0=loglog(E,en,miu,N,1);
		y1=loglog(E,en,tau,N,1);	
	  }
	  if ((E>EL1)&(E<=EK))
	  {
		N=9;
		double en[] ={1.008E+00,1.500E+00,2.000E+00,3.000E+00,4.000E+00,5.000E+00,6.000E+00,8.000E+00,8.333E+00};
		double miu[]={1.099E+04,4.234E+03,2.048E+03,7.095E+02,3.282E+02,1.793E+02,1.090E+02,4.952E+01,4.428E+01};
	    double tau[]={1.099E+04,4.230E+03,2.044E+03,7.056E+02,3.249E+02,1.764E+02,1.065E+02,4.764E+01,4.247E+01};
		y0=loglog(E,en,miu,N,1);
		y1=loglog(E,en,tau,N,1);	
	  }
	  if (E>EK)
	  {
		N=10;
		double en[] ={8.333E+00,1.000E+01,1.500E+01,2.000E+01,3.000E+01,4.000E+01,5.000E+01,6.000E+01,8.000E+01,1.000E+02}; 
		double miu[]={3.293E+02,2.090E+02,7.081E+01,3.220E+01,1.034E+01,4.600E+00,2.474E+00,1.511E+00,7.306E-01,4.439E-01}; 
	    double tau[]={3.275E+02,2.075E+02,6.985E+01,3.149E+01,9.883E+00,4.256E+00,2.193E+00,1.267E+00,5.300E-01,2.680E-01};
		y0=loglog(E,en,miu,N,2);
		y1=loglog(E,en,tau,N,2);		
	  }
	} 
	if (Z==29.0) //Copper (Cu) mass att. coeff. in the 1 keV to 100 keV photon energy range from log-log cubic spline interpolation of XCOM data//
	{
      EL1=1.096E+00;
	  EK=8.979E+00;
	  if (E<=EL1)
	  {
		N=3;
		double en[] ={1.000E+00,1.047E+00,1.096E+00}; 
		double miu[]={1.057E+04,9.333E+03,8.245E+03};
	    double tau[]={1.057E+04,9.328E+03,8.240E+03};	
		y0=loglog(E,en,miu,N,1);
		y1=loglog(E,en,tau,N,1);
	  }
	  if ((E>EL1)&(E<=EK))
	  {
		N=9;
		double en[] ={1.096E+00,1.500E+00,2.000E+00,3.000E+00,4.000E+00,5.000E+00,6.000E+00,8.000E+00,8.979E+00}; 
		double miu[]={9.345E+03,4.418E+03,2.154E+03,7.488E+02,3.473E+02,1.899E+02,1.156E+02,5.255E+01,3.829E+01};
	    double tau[]={9.340E+03,4.413E+03,2.149E+03,7.449E+02,3.439E+02,1.870E+02,1.131E+02,5.062E+01,3.657E+01};	
		y0=loglog(E,en,miu,N,1);
		y1=loglog(E,en,tau,N,1);	
	  }
	  if(E>EK)
	  {
		N=10;		
		double en[] ={8.979E+00,1.000E+01,1.500E+01,2.000E+01,3.000E+01,4.000E+01,5.000E+01,6.000E+01,8.000E+01,1.000E+02};
		double miu[]={2.783E+02,2.160E+02,7.405E+01,3.380E+01,1.091E+01,4.862E+00,2.613E+00,1.593E+00,7.630E-01,4.585E-01};
	    double tau[]={2.766E+02,2.145E+02,7.308E+01,3.308E+01,1.045E+01,4.520E+00,2.335E+00,1.353E+00,5.676E-01,2.878E-01};
		y0=loglog(E,en,miu,N,2);
		y1=loglog(E,en,tau,N,2);		
	  }
	} 
	if (Z==30.0) //Zinc (Zn) mass att. coeff. in the 1 keV to 100 keV photon energy range from log-log cubic spline interpolation of XCOM data//
	{
      EL1=1.194E+00;
	  EL2=1.043E+00;
	  EL3=1.020E+00;
	  EK=9.659E+00;
	  if (E<=EL3)
	  {
		N=3;
		double en[] ={1.000E+00,1.010E+00,1.020E+00}; 
		double miu[]={1.553E+03,1.518E+03,1.484E+03};
	    double tau[]={1.548E+03,1.513E+03,1.479E+03};
		y0=loglog(E,en,miu,N,1);
		y1=loglog(E,en,tau,N,1);		
	  }
	  if ((E>EL3)&(E<=EL2))
	  {
		N=3;
		double en[] ={1.020E+00,1.031E+00,1.043E+00}; 
		double miu[]={3.526E+03,4.786E+03,6.493E+03};
	    double tau[]={3.521E+03,4.781E+03,6.488E+03};
		y0=loglog(E,en,miu,N,1);
		y1=loglog(E,en,tau,N,1);		
	  }
	  if ((E>EL2)&(E<=EL1))
	  {
		N=3;
		double en[] ={1.043E+00,1.116E+00,1.194E+00};
		double miu[]={8.239E+03,7.793E+03,7.373E+03};
	    double tau[]={8.233E+03,7.788E+03,7.368E+03};
		y0=loglog(E,en,miu,N,1);
		y1=loglog(E,en,tau,N,1);	
	  }
	  if ((E>EL1)&(E<=EK))
	  {
		N=9;
		double en[] ={1.194E+00,1.500E+00,2.000E+00,3.000E+00,4.000E+00,5.000E+00,6.000E+00,8.000E+00,9.659E+00};
		double miu[]={8.396E+03,4.824E+03,2.374E+03,8.311E+02,3.866E+02,2.118E+02,1.290E+02,5.874E+01,3.506E+01};
	    double tau[]={8.391E+03,4.819E+03,2.370E+03,8.270E+02,3.830E+02,2.087E+02,1.264E+02,5.668E+01,3.338E+01};
		y0=loglog(E,en,miu,N,1);
		y1=loglog(E,en,tau,N,1);
	  }
	  if (E>EK)
	  {
		N=10;
		double en[] ={9.659E+00,1.000E+01,1.500E+01,2.000E+01,3.000E+01,4.000E+01,5.000E+01,6.000E+01,8.000E+01,1.000E+02};
		double miu[]={2.536E+02,2.331E+02,8.117E+01,3.719E+01,1.207E+01,5.384E+00,2.892E+00,1.760E+00,8.365E-01,4.973E-01};
		double tau[]={2.519E+02,2.314E+02,8.014E+01,3.644E+01,1.159E+01,5.029E+00,2.605E+00,1.514E+00,6.367E-01,3.235E-01};
		y0=loglog(E,en,miu,N,2);
		y1=loglog(E,en,tau,N,2);		
	  }	  
	}	 
	if (Z==33.0) //Arsenic (As) mass att. coeff. in the 1 keV to 100 keV photon energy range from log-log cubic spline interpolation of XCOM data//
	{
      EL1=1.526E+00;
	  EL2=1.359E+00;
	  EL3=1.323E+00;
	  EK=1.187E+01;
	 if (E<=EL3)
	 {
		N=3; 
		double en[] ={1.000E+00,1.150E+00,1.323E+00}; 
		double miu[]={2.121E+03,1.522E+03,1.092E+03};	
	    double tau[]={2.116E+03,1.517E+03,1.087E+03};
		y0=loglog(E,en,miu,N,1);
		y1=loglog(E,en,tau,N,1);
	 }
     if ((E>EL3)&(E<=EL2))
	 {
		N=3;
		double en[] ={1.323E+00,1.341E+00,1.359E+00}; 
		double miu[]={4.532E+03,4.489E+03,4.446E+03};   
	    double tau[]={4.527E+03,4.484E+03,4.441E+03};
		y0=loglog(E,en,miu,N,1);
		y1=loglog(E,en,tau,N,1);		
	 }	
     if ((E>EL2)&(E<=EL1))
	 {
		N=3;
		double en[] ={1.359E+00,1.500E+00,1.526E+00}; 
		double miu[]={6.083E+03,5.226E+03,4.998E+03};  
	    double tau[]={6.077E+03,5.221E+03,4.992E+03};
		y0=loglog(E,en,miu,N,1);
		y1=loglog(E,en,tau,N,1);
	 }
     if ((E>EL1)&(E<=EK))
	 {
		N=9;
		double en[]={1.526,2.000,3.000,4.000,5.000,6.000,8.000,1.000E1,1.187E1};
		double miu[]={5.653E+03,2.931E+03,1.049E+03,4.921E+02,2.709E+02,1.656E+02,7.573E+01,4.115E+01,2.577E+01};
	    double tau[]={5.648E+03,2.927E+03,1.045E+03,4.884E+02,2.677E+02,1.628E+02,7.349E+01,3.937E+01,2.430E+01};
		y0=loglog(E,en,miu,N,1);
		y1=loglog(E,en,tau,N,1);		
	 }
	 if (E>EK)
	 {
		N=9;
	    double en[] ={1.187E+01,1.500E+01,2.000E+01,3.000E+01,4.000E+01,5.000E+01,6.000E+01,8.000E+01,1.000E+02};
        double miu[]={1.793E+02,9.854E+01,4.564E+01,1.505E+01,6.761E+00,3.635E+00,2.203E+00,1.030E+00,5.971E-01};	
	    double tau[]={1.778E+02,9.742E+01,4.484E+01,1.454E+01,6.386E+00,3.336E+00,1.950E+00,8.279E-01,4.234E-01};
		y0=loglog(E,en,miu,N,2);
		y1=loglog(E,en,tau,N,2);	
	 }
	}
	if (Z==34.0) //Selenium (Se) mass att. coeff. in the 1 keV to 100 keV photon energy range from log-log cubic spline interpolation of XCOM data//
	{
      EL1=1.654E+00;
	  EL2=1.476E+00;
	  EL3=1.436E+00;
	  EK=1.266E+01;
	  if (E<=EL3)
	  { 
        N=3;
		double en[] ={1.000E+00,1.198E+00,1.436E+00}; 
		double miu[]={2.317E+03,1.507E+03,9.815E+02};		
	    double tau[]={2.312E+03,1.502E+03,9.762E+02};
		y0=loglog(E,en,miu,N,1);
		y1=loglog(E,en,tau,N,1);
	  }
      if ((E>EL3)&(E<=EL2))
	  {
		N=3;
	    double en[] ={1.436E+00,1.456E+00,1.476E+00}; 
		double miu[]={4.349E+03,4.122E+03,3.907E+03};     
	    double tau[]={4.343E+03,4.117E+03,3.902E+03};
		y0=loglog(E,en,miu,N,1);
		y1=loglog(E,en,tau,N,1);
	  }
      if ((E>EL2)&(E<=EL1))
	  {
		N=3;  
		double en[] ={1.476E+00,1.500E+00,1.654E+00};
		double miu[]={5.594E+03,5.336E+03,4.343E+03};     
	    double tau[]={5.589E+03,5.330E+03,4.337E+03};
		y0=loglog(E,en,miu,N,1);
		y1=loglog(E,en,tau,N,1);
	  }
      if ((E>EL1)&(E<=EK))
	  {
		N=9;
		double en[] ={1.654E+00,2.000E+00,3.000E+00,4.000E+00,5.000E+00,6.000E+00,8.000E+00,1.000E+01,1.266E+01};
		double miu[]={4.915E+03,3.098E+03,1.116E+03,5.252E+02,2.896E+02,1.773E+02,8.113E+01,4.413E+01,2.318E+01};
	    double tau[]={4.910E+03,3.093E+03,1.112E+03,5.214E+02,2.864E+02,1.744E+02,7.886E+01,4.232E+01,2.179E+01};
		y0=loglog(E,en,miu,N,1);
		y1=loglog(E,en,tau,N,1);
	  }
      if (E>EK)
	  {
		N=9;
		double en[] ={1.266E+01,1.500E+01,2.000E+01,3.000E+01,4.000E+01,5.000E+01,6.000E+01,8.000E+01,1.000E+02};
		double miu[]={1.589E+02,1.033E+02,4.818E+01,1.596E+01,7.184E+00,3.864E+00,2.341E+00,1.090E+00,6.278E-01};
	    double tau[]={1.575E+02,1.021E+02,4.736E+01,1.544E+01,6.806E+00,3.564E+00,2.087E+00,8.893E-01,4.558E-01};
		y0=loglog(E,en,miu,N,2);
		y1=loglog(E,en,tau,N,2);		
	  }
	}
	if (Z==38.0) //Strontium (Sr) mass att. coeff. in the 1 keV to 100 keV photon energy range from log-log cubic spline interpolation of XCOM data//
	{
      EL1=2.216E+00;
	  EL2=2.007E+00;
	  EL3=1.940E+00;
	  EK=1.610E+01;
	  if (E<=EL3)
	  {
		N=3;
		double en[]= {1.000E+00,1.500E+00,1.940E+00}; 
		double miu[]={3.493E+03,1.347E+03,7.209E+02};
	    double tau[]={3.487E+03,1.341E+03,7.155E+02};
		y0=loglog(E,en,miu,N,1);
		y1=loglog(E,en,tau,N,1);		
	  }
      if ((E>EL3)&(E<=EL2))
	  {
		N=3;
		double en[]= {1.940E+00,2.000E+00,2.007E+00}; 
		double miu[]={2.863E+03,2.590E+03,2.572E+03}; 
	    double tau[]={2.858E+03,2.584E+03,2.566E+03};
		y0=loglog(E,en,miu,N,1);
		y1=loglog(E,en,tau,N,1);
	  }
      if ((E>EL2)&(E<=EL1))
	  {
		N=3;
		double en[] ={2.007E+00,2.109E+00,2.216E+00}; 
		double miu[]={3.578E+03,3.189E+03,2.842E+03};
	    double tau[]={3.573E+03,3.184E+03,2.837E+03};
		y0=loglog(E,en,miu,N,1);
		y1=loglog(E,en,tau,N,1);	
	  }
      if ((E>EL1)&(E<=EK))
	  {
		N=9;
		double en[] ={2.216E+00,3.000E+00,4.000E+00,5.000E+00,6.000E+00,8.000E+00,1.000E+01,1.500E+01,1.610E+01};
		double miu[]={3.241E+03,1.526E+03,7.299E+02,4.058E+02,2.496E+02,1.150E+02,6.274E+01,2.079E+01,1.714E+01};
	    double tau[]={3.236E+03,1.521E+03,7.258E+02,4.022E+02,2.464E+02,1.124E+02,6.065E+01,1.946E+01,1.591E+01};
		y0=loglog(E,en,miu,N,1);
		y1=loglog(E,en,tau,N,1);	
	  }
      if (E>EK)
	  {
		N=8;
		double en[] ={1.610E+01,2.000E+01,3.000E+01,4.000E+01,5.000E+01,6.000E+01,8.000E+01,1.000E+02};
		double miu[]={1.109E+02,6.386E+01,2.156E+01,9.816E+00,5.305E+00,3.214E+00,1.481E+00,8.365E-01};
	    double tau[]={1.096E+02,6.292E+01,2.097E+01,9.389E+00,4.970E+00,2.935E+00,1.265E+00,6.536E-01};
		y0=loglog(E,en,miu,N,2);
		y1=loglog(E,en,tau,N,2);
	  }		
	}
   if (a==0)
   {y=y0;}
   else
   {y=y1;}
   return y;
 }
 
 /* --- KXRF factor: V*w*g*tau(E) in cm^2/g units, V=prob. K hole, w=K fluoresc. yield, g=prob. Ka or Kb, tau(E)=photo. abs. coeff. at E ---*/
 /* --- KXRF factor for 14 elements: P,S,Cl,K,Ca,Mn,Fe,Co,Ni,Cu,Zn,As,Se,Sr. ---------------------------------------------------------------*/
 /* --- FP values from Elam et al, "A new atomic database for X-ray spectroscopic calculations", Rad. Phys. Chem. 63 (2002) 121-128 --------*/
 /* --- Ka and Kb probabilities were computed from measurements of Ertugral et al., "Kb/Ka ratios for elements in the range 16<Z<92..." ----*/ 
 /* --- Variable q=1.0 for Ka and q=2.0 for Kb ---------------------------------------------------------------------------------------------*/
 double kxrf (double Z, double E, double q)
 {
	double x,y,J,w,g,V,tau;
	
	if ((Z==15.0)&(E>2.145)) //Phosphorus (P) KXRF excitability factor at photon energy E//
	{
	  J=9.969;
	  w=5.54775E-02;
	  V=1.0-(1.0/J);
	  if (q==1.0)
	  {g=0.8874;}
      else
	  {g=0.1126;}
      tau=matt(Z,E,1);
	  y=V*w*g*tau;
	}
    if ((Z==15.0)&(E<2.145))
	 {y=0.0;}		
	if ((Z==16.0)&(E>2.472)) //Sulphur (S) KXRF excitability factor at photon energy E//
	{
	  J=9.613;
	  w=7.06768E-02;
	  V=1.0-(1.0/J);
	  if (q==1.0)
	  {g=0.944;}
      else
	  {g=0.056;}
      tau=matt(Z,E,1);
	  y=V*w*g*tau;
	}	
	if ((Z==16.0)&(E<2.472))
	 {y=0.0;}
	if ((Z==17.0)&(E>2.822)) //Chlorine (Cl) KXRF excitability factor at photon energy E//
	{
	  J=9.309;
	  w=8.85087E-02;
	  V=1.0-(1.0/J);
	  if (q==1.0)
	  {g=0.935;}
      else
	  {g=0.065;}
      tau=matt(Z,E,1);
	  y=V*w*g*tau;
	}
    if ((Z==17.0)&(E<2.822))
	{y=0.0;}		
	if ((Z==19.0)&(E>3.608)) //Potassium (K) KXRF excitability factor at photon energy E//
	{
	  J=9.163;
	  w=1.32070E-01;
	  V=1.0-(1.0/J);
	  if (q==1.0)
	  {g=0.899;}
      else
	  {g=0.101;}
      tau=matt(Z,E,1);
	  y=V*w*g*tau;
	}
    if ((Z==19.0)&(E<3.608))
	{y=0.0;}		
	if ((Z==20.0)&(E>4.038)) //Calcium (Ca) KXRF excitability factor at photon energy E//
	{
	  J=8.744;
	  w=1.46786E-01;
	  V=1.0-(1.0/J);
	  if (q==1.0)
	  {g=0.891;}
      else
	  {g=0.109;}
      tau=matt(Z,E,1);
	  y=V*w*g*tau;
	}
    if ((Z==20.0)&(E<4.038))
    {y=0.0;}		
	if ((Z==25.0)&(E>6.539)) //Manganese (Mn) KXRF excitability factor at photon energy E//
	{
	  J=7.999;
	  w=3.19181E-01;
	  V=1.0-(1.0/J);
	  if (q==1.0)
	  {g=0.874;}
      else
	  {g=0.126;}
      tau=matt(Z,E,1);
	  y=V*w*g*tau;
	}
    if ((Z==25.0)&(E<6.539))
	{y=0.0;}		
	if ((Z==26.0)&(E>7.112)) //Iron (Fe) KXRF excitability factor at photon energy E//
	{
	  J=7.893;
	  w=3.50985E-01;
	  V=1.0-(1.0/J);
	  if (q==1.0)
	  {g=0.883;}
      else
	  {g=0.117;}
      tau=matt(Z,E,1);
	  y=V*w*g*tau;
	}
    if ((Z==26.0)&(E<7.112))
    {y=0.0;}		
	if ((Z==27.0)&(E>7.709)) //Cobalt (Co) KXRF excitability factor at photon energy E//
	{
	  J=7.796;
	  w=3.81903E-01;
	  V=1.0-(1.0/J);
	  if (q==1.0)
	  {g=0.878;}
      else
	  {g=0.122;}
      tau=matt(Z,E,1);
	  y=V*w*g*tau;
	}
    if ((Z==27.0)&(E<7.709))
	{y=0.0;}		
	if ((Z==28.0)&(E>8.333)) //Nickel (Ni) KXRF excitability factor at photon energy E//
	{
	  J=7.707;
	  w=4.11937E-01;
	  V=1.0-(1.0/J);
	  if (q==1.0)
	  {g=0.883;}
      else
	  {g=0.117;}
      tau=matt(Z,E,1);
	  y=V*w*g*tau;
	}
    if ((Z==28.0)&(E<8.333))
	{y=0.0;}		
	if ((Z==29.0)&(E>8.979)) //Copper (Cu) KXRF excitability factor at photon energy E//
	{
	  J=7.560;
	  w=4.41091E-01;
	  V=1.0-(1.0/J);
	  if (q==1.0)
	  {g=0.880;}
      else
	  {g=0.120;}
      tau=matt(Z,E,1);
	  y=V*w*g*tau;
	}
    if ((Z==29.0)&(E<8.979))
	{y=0.0;}		
	if ((Z==30.0)&(E>9.569)) //Zinc (Zn) KXRF excitability factor at photon energy E//
	{
	  J=7.543;
	  w=4.69369E-01;
	  V=1.0-(1.0/J);
	  if (q==1.0)
	  {g=0.879;}
      else
	  {g=0.121;}
      tau=matt(Z,E,1);
	  y=V*w*g*tau;
	}
    if ((Z==30.0)&(E<9.569))
	{y=0.0;}		
	if ((Z==33.0)&(E>11.867)) //Arsenic (As) KXRF excitability factor at photon energy E//
	{
	  J=7.314;
	  w=5.48989E-01;
	  V=1.0-(1.0/J);
	  if (q==1.0)
	  {g=0.869;}
      else
	  {g=0.131;}
      tau=matt(Z,E,1);
	  y=V*w*g*tau;
	}
    if ((Z==33.0)&(E<11.867))
	{y=0.0;}		
	if ((Z==34.0)&(E>12.658)) //Selenium (Se) KXRF excitability factor at photon energy E//
	{
	  J=7.225;
	  w=5.73809E-01;
	  V=1.0-(1.0/J);
	  if (q==1.0)
	  {g=0.861;}
      else
	  {g=0.139;}
      tau=matt(Z,E,1);
	  y=V*w*g*tau;
	}
    if ((Z==34.0)&(E<12.658))
	{y=0.0;}		
	if ((Z==38.0)&(E>16.105)) //Strontium (Sr) KXRF excitability factor at photon energy E//
	{
	  J=6.888;
	  w=6.64652E-01;
	  V=1.0-(1.0/J);
	  if (q==1.0)
	  {g=0.847;}
      else
	  {g=0.153;}
      tau=matt(Z,E,1);
	  y=V*w*g*tau;
	} 
	if ((Z==38.0)&(E<16.105))
	{y=0.0;}
   return y;	
 } 

 //--X-ray detector quantum detection efficiency: E=photon energy in keV in (2-20) kev; teta=angle (normal to detector & photon direction)---//  
 double qde (double E, double teta)
 {
   double dsd=20.0;                 // distance between sample and detector in mm                               //
   double miuSi=roSi*matt(14,E,0);  // linear attenuation coefficient of Si at photon energy E in cm^(-1) units //
   double miuBe=roBe*matt(4,E,0);   // linear attenuation coefficient of Be at photon energy E in cm^(-1) units //	
   return exp((-1.0)*miuBe*tBe/cos(teta))*(1.0-exp((-1.0)*miuSi*tSi/cos(teta))); 
 }
 
 //Function computing linear attenuation coefficient of lamb bone miub in mm^(-1) at photon energy E in keV --------------------------- //
 double miub (double E)
 {
    double lnE=log(E);
	double lnm=8.5-3.06*lnE;
    return exp(lnm); 
 }
 //lamb cortical bone: elemental composition of human cortical bone & mass density rob = 1.9 g/cm^3 [Zhou, Med.Phys.36,1008-1018,2009] // 
 /* double miub (double E, double ro)
 {
   double m;
   double cb[13];   // array for elemental concentrations of human cortical bone in percentages by mass //
   cb[1]= 3.387;    // Hydrogen (H),   Z=1,  percentage concentration by mass //
   cb[2]= 15.488;   // Carbon (C),     Z=6,  percentage concentration by mass //
   cb[3]= 3.966;    // Nitrogen (N),   Z=7,  percentage concentration by mass //
   cb[4]= 44.065;   // Oxygen (O),     Z=8,  percentage concentration by mass //
   cb[5]= 0.060;    // Sodium (Na),    Z=11, percentage concentration by mass //
   cb[6]= 0.210;    // Magnesium (Mg), Z=12, percentage concentration by mass // 
   cb[7]= 10.192;   // Phosphorus (P), Z=15, percentage concentration by mass //
   cb[8]= 0.310;    // Sulfur (S),     Z=16, percentage concentration by mass //
   cb[9]= 0.100;    // Chlorine (S),   Z=17, percentage concentration by mass //
   cb[10]=0.030;    // Potassium (K),  Z=19, percentage concentration by mass //
   cb[11]=22.182;   // Calcium (Ca),   Z=20, percentage concentration by mass //
   cb[12]=0.010;    // Iron (Fe),      Z=26, percentage concentration by mass //
   
   double cpoP[7];  //array for elemental concentrations of plaster-of-Paris (poP) in percentages by mass //
   cpoP[1]= 0.694;   // Hydrogen (H),   Z=1,  percentage concentration by mass //
   cpoP[2]= 49.553;  // Carbon (C),     Z=6,  percentage concentration by mass //
   cpoP[3]= 22.069;  // Sulfur (S),     Z=16, percentage concentration by mass //
   cpoP[4]= 27.584;  // Calcium (Ca)    Z=20, percentage concentration by mass //
   cpoP[5]= 0.101;   // Strontium (Sr)  Z=38, percentage concentration by mass //
   
   double z[14];   //array for atomic numbers //
   z[1]=1.0; z[2]=6.0; z[3]=7.0; z[4]=8.0, z[5]=11.0; z[6]=12.0; z[7]=15.0; z[8]=16.0; z[9]=17.0; z[10]=19.0; z[11]=20.0; z[12]=26.0; z[13]=38.0;
   
   double s1 = (cpoP[1]*matt(z[1],E,0)+cpoP[2]*matt(z[2],E,0)+cpoP[3]*matt(z[8],E,0)+cpoP[4]*matt(z[11],E,0)+cpoP[5]*matt(z[13],E,0))/100.0;
   double s2=0.0;
   for (int i=1;i<=12;i++)
   {s2=s2+(cb[i]/100.0)*matt(z[i],E,0);}
   return s2*ro*0.1;
 }
 */
 
 //-- Function computing linear attenuation coefficient of leather (soft tissue phantom) miust in mm^(-1) at photon energy E in keV --// 
 double miust (double E)
 {
	double lnE=log(E);
	double lnm=5.4-2.94*lnE;
    return exp(lnm);
 }
 
 /*---------- Computation of the integrating function ---------------------------------------------------------------*/
   // Z = atomic number of trace element (TE) in bone ----------------------//
   // E = incident photon energy -------------------------------------------//
   // d = distance between microbeam direction and detector center in mm ---//
   // x = bone position in mm along microbeam between -l/2 and l/2 ---------//
 
   // q = 1 ---> Kalpha component of KXRF emissions -------------------------//
   // q = 2 ---> Kbeta  component of KXRF emissions -------------------------//
   
   // w = 1 ---> bare bone --> air layer with negligible x-ray attenuation --//
   // w = 2 ---> leather soft tissue phantom --------------------------------//
 
 double Kf (double Z, double a, double b, double t0, double ro, int q, int w, double E, double d, double x)
 { 
   double y0,l,lp,tst,EK,mst0,mst1,mb0,mb1,teta,tb,t,omega,G,S,f,deff;                                          
   y0   = Lc+t0+b;                                     // distance between bone ellipse center and detector center in mm       //
   l    = 2.0*a*sqrt(1.0-pow((y0-d)/b,2.0));           // distance in bone along microbeam direction in mm                     //
   lp   = 2.0*(a+t0)*sqrt(1.0-pow((y0-d)/(b+t0),2.0)); // distance in bone and soft tissue along microbeam direction in mm     //
   tst  = (lp-l)/2.0;                                  // distance in soft tissue or air along the microbeam before bone in mm //
   EK   = Ken(Z,q);                                    // photon energy in keV of Ka or Kb of trace element of atomic number Z //
   if (w==1)
   {
	mst0 = 0.0;                                        // linear attenuation coefficient of soft tissue at incident photon energy E  //
    mst1 = 0.0;                                        // linear attenuation coefficient of soft tissue at KXRF photon energy  Ea/Eb  //    
   }
   if (w==2)
   {
    mst0 = miust(E);                                   // linear attenuation coefficient of soft tissue in mm^(-1) at incident photon energy   //
    mst1 = miust(EK);                                  // linear attenuation coefficient of soft tissue in mm^(-1) at KXRF photon energy Ea/Eb //    
   }
   mb0  = miub(E);                                     // linear attenuation coefficient of bone in mm^(-1) at incident photon energy E  //
   mb1  = miub(EK);                                    // linear attenuation coefficient of bone in mm^(-1) at KXRF photon energy  Ea/Eb // 
   teta = atan(x/d);                                   // angle between y-axis and line connecting bone element dl and detector center   //
   tb   = (d-(Lc+t0))/cos(teta);                       // distance crossed by KXRF photon in bone                                        //
   if (tb<=0.0)
    {f=0.0;}
   else
	{
	 t     = t0/(cos(teta));                                // distance crossed by KXRF photon in air or soft tissue                         //
     omega = (pi*Dd*Dd/(4.0*(d*d)))*cos(teta);              // solid angle of KXRF emitted by element dl at position x reaching the detector //
     G     = omega/(4.0*pi);                                // geometric factor                                                              //  
     S     = kxrf(Z,E,double(q))*ro*0.1*exp(-1.0*mst0*tst); // constant for trace element Z, KXRF given by q in units of mm^(-1)             //
	 deff  = qde (EK,teta);                                 // detector efficiency at KXRF photon energy EK and angle teta                   //
     f     = S*G*deff*exp(-1.0*(mb0*x+mb1*tb+mst1*t));      // integrating function in units of mm^(-1)                                      //   	
	}
   return f;  
 }

 // Numerical integration using trapezoidal method over various x values between -l/2 and l/2 (x = position in the bone along the microbeam direction) //
 
 double IK (double Z, double a, double b, double t0, double ro, int q, int w, double E, double d)
 {
	double y0,l,x,dx;
	int n;
    int Nmax = 5000;	
	double fv[Nmax];
	double s  = 0.0;
	double epsilon = pow(10.0,-8.0);       // numerical precision //
	double olds = 0.5;
	double rv;
	y0 = Lc+t0+b;                          // distance between bone ellipse center and detector center in mm  //
	l = 2.0*a*sqrt(1.0-pow((y0-d)/b,2.0)); // distance in bone along microbeam direction in mm               //
	s = 0.0;
    n=0; 
    while ((fabs(s-olds))>epsilon)         
     {
	  n = n+1;
	  dx=l/double(n+1);                     // n+1 equal intervals of length dx dividing bone length l //
	  x=(-0.5)*l;                           // initial value of integrating variable x in mm               // 
	  for (int i=0;i<=(n+1);i++)            // generates n+2 values of the function including the boundary values //
	   {
		 fv[i] = Kf(Z,a,b,t0,ro,q,w,E,d,x);      
		 x = x+dx;
       }
	  olds=s; 
	  s=trapez(n,dx,fv);
     } 
	return s;
 } 
 
 //Numerical integration over microbeam photon energy spectrum of Kalpha fundamental parameters factor from function IK //    
 double SumEn (double Z, double a, double b, double t0, double ro, int q, int w, double d)
 {
   double s = 0.0;
   int    N = 20;
   double E[22],we[22];
   we[0]=3.15E-05; we[1]=6.91E-04; we[2]=7.27E-03; we[3]=3.78E-02; we[4]=1.02E-01; we[5]=1.57E-01; we[6]=1.61E-01;
   we[7]=1.32E-01; we[8]=1.01E-01; we[9]=7.63E-02; we[10]=5.76E-02; we[11]=4.36E-02; we[12]=3.29E-02; we[13]=2.49E-02; we[14]=1.88E-02;
   we[15]=1.42E-02; we[16]=1.07E-02; we[17]=8.12E-03; we[18]=6.14E-03; we[19]=4.64E-03; we[20]=3.51E-03; 
   for (int i=0;i<=N;i++)
    {
	 E[i]=10.0+double(i)*2.0;                 //array of photon energies from 10 keV to 50 keV //
	 s=s+we[i]*IK(Z,a,b,t0,ro,q,w,E[i],d);    
	}
  return s;
 }  
 
 /*------------------------------------------------------------ MAIN PROGRAM -------------------------------------------------------------------------*/

  using namespace std; 
  int main ()
{ 
  double y0,t0,ro,tb,ertb,a,b,E,d,l,Ea,Eb,NKa,NKb,step,CaKa,CaKb,SrKa,SrKb,ratio; 
  int w;
  int N=5;
  double Z[]={15.0,16.0,19.0,20.0,38.0}; 
  double Ka[N],erKa[N],Kb[N],erKb[N];
  
  cout<<" Please see the density and geometrical properties of: "<<endl;
  cout<<" (1) plaster-of-Paris (poP) bone phantom cylinder "<<endl;
  cout<<" (2) lamb bone "<<endl;
  cout<<" Please modify accordingly the miub function: "<< endl;
  cout<<"   for (1), select s1 as the output variable. "<<endl;
  cout<<"   for (2), select s2 as the output variable. "<<endl; 
  cout<<" Lamb bone   : a = 6.5 mm  & b = 8.3 mm  "<<endl;
  cout<<" poP cylinder: a = 13.9 mm & b = 13.9 mm "<<endl;
  cout<<" Lamb bone density is: 1.90 g/cm^3 "<<endl;
  cout<<" poP density is:       1.04 g/cm^3 "<<endl;
  cout<<endl;
  cout<<" Give parameter a in mm: a = ";
  cin>>a;
  cout<<" Give parameter b in mm: b = ";
  cin>>b;
  cout<<" Give sample density in g/cm^3, ro = ";
  cin>>ro;
  
  //-----------------------------------------------------------------------------------------------------------//
  
  cout<<" Choose of the two options: (1) bare bone (w = 1) OR (2) bone & soft tissue (w = 2) w = ";
  cin>>w;
  if (w==1)
  {t0=0.0;}
  else
  {t0=2.80;}
   
  int q=1;      // variable required for choosing between Ka and Kb options //
  y0 = Lc+t0+b; // distance between bone ellipse center and detector center in mm                      //
  d  = Lc+t0;   // distance between bone or bone and soft tissue surface and detector along the y-axis //
  cout<<" Distance between elliptical center and detector center is:          y0 = "<<y0<<" mm"<<endl;
  cout<<" Distance between elliptical bone boundary and the x-ray detector is: d = "<<d <<" mm"<<endl;
  cout<<endl;
   
  double time0 = time(0);
   
   /*
   double NCa;
   step = 0.0005;  //incremental step in mm for distance d //
   NCa  = 1000;
   ofstream q1;
   q1.open ("Ca_data.dat");   
   for (int i=0;i<=NCa;i++)
   {
	d = (Lc+t0)+double(i)*step;
	CaKa=SumEn(Z[3],a,b,t0,ro,q,w,d);  
	CaKb=SumEn(Z[3],a,b,t0,ro,q+1,w,d);
	q1<<d<<" "<<CaKa<<" "<<CaKb<<endl;  
   }
   q1.close();
   */
   
   int NSr;
   step = 0.05;  //incremental step in mm for distance d //
   NSr  = 200;
   ofstream q2;
   q2.open ("Sr_LBOL_data.dat");     
   for (int i=0;i<=NSr;i++)
   {
	d = (Lc+t0)+double(i)*step;
	SrKa=SumEn(Z[4],a,b,t0,ro,q,w,d);
	SrKb=SumEn(Z[4],a,b,t0,ro,q+1,w,d);
	q2<<d<<" "<<SrKa<<" "<<SrKb<<endl;  
   }   
  q2.close();  

 double time1 = time (0);
 cout<<" The running time of the C++ code was delta(t) = "<<time1-time0<<" seconds"<<endl;
 
}

//--------------------------------------------------------- THE END -----------------------------------------------------------------------------------------//
